@@ -267,8 +267,12 @@ static int dhcpc_sendmsg(FAR struct dhcpc_state_s *pdhcpc,
       /* Broadcast DISCOVER message to all servers */
 
       case DHCPDISCOVER:
-        /* REVISIT: We don't need the broadcast flag since we can receive
-         * unicast traffic before being fully configured.
+        /* Socket binded to INADDR_ANY is not intended to receive unicast
+         * traffic before being fully configured, at least dhclient
+         * configured with socket-only won't do so on Linux and BSDs.
+         * We can sometimes receive unicast traffic before being fully
+         * configured, it's good, but not always, so we need to set the
+         * broadcast flag under some situations.
          */
 
         /* Broadcast bit. */
@@ -283,9 +287,6 @@ static int dhcpc_sendmsg(FAR struct dhcpc_state_s *pdhcpc,
       /* Send REQUEST message to the server that sent the *first* OFFER */
 
       case DHCPREQUEST:
-        /* REVISIT: We don't need the broadcast flag since we can receive
-         * unicast traffic before being fully configured.
-         */
 
         /* Broadcast bit. */
 
@@ -306,6 +307,7 @@ static int dhcpc_sendmsg(FAR struct dhcpc_state_s *pdhcpc,
         break;
 
       default:
+        errno = EINVAL;
         return ERROR;
     }
 
@@ -729,6 +731,7 @@ int dhcpc_request(FAR void *handle, FAR struct dhcpc_state *presult)
     {
       if (pdhcpc->cancel)
         {
+          errno = EINTR;
           return ERROR;
         }
 
@@ -807,6 +810,7 @@ int dhcpc_request(FAR void *handle, FAR struct dhcpc_state *presult)
     {
       if (pdhcpc->cancel)
         {
+          errno = EINTR;
           return ERROR;
         }
 
@@ -852,6 +856,7 @@ int dhcpc_request(FAR void *handle, FAR struct dhcpc_state *presult)
                   ninfo("Received NAK\n");
                   oldaddr.s_addr = INADDR_ANY;
                   netlib_set_ipv4addr(pdhcpc->interface, &oldaddr);
+                  errno = ECONNREFUSED;
                   return ERROR;
                 }
 
@@ -937,12 +942,14 @@ int dhcpc_request_async(FAR void *handle, dhcpc_callback_t callback)
 
   if (!handle || !callback)
     {
+      errno = EINVAL;
       return ERROR;
     }
 
   if (pdhcpc->thread)
     {
       nerr("ERROR: DHCPC thread already running\n");
+      errno = EALREADY;
       return ERROR;
     }
 
@@ -951,6 +958,7 @@ int dhcpc_request_async(FAR void *handle, dhcpc_callback_t callback)
   if (ret != 0)
     {
       nerr("ERROR: Failed to start the DHCPC thread\n");
+      errno = ret;
       return ERROR;
     }
 
