@@ -60,6 +60,8 @@
 
 #undef CAN_PIPE_FROM_STD
 
+#define g_dd "dd"
+
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -74,17 +76,11 @@ struct dd_s
   uint32_t     skip;       /* The number of sectors skipped on input */
   bool         eof;        /* true: The end of the input or output file has been hit */
   bool         verify;     /* true: Verify infile and outfile correctness */
-  uint16_t     sectsize;   /* Size of one sector */
-  uint16_t     nbytes;     /* Number of valid bytes in the buffer */
+  size_t       sectsize;   /* Size of one sector */
+  size_t       nbytes;     /* Number of valid bytes in the buffer */
   FAR uint8_t *buffer;     /* Buffer of data to write to the output file */
 };
 
-/****************************************************************************
- * Private Data
- ****************************************************************************/
-
-static const char g_dd[] = "dd";
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -96,7 +92,7 @@ static const char g_dd[] = "dd";
 static int dd_write(FAR struct dd_s *dd)
 {
   FAR uint8_t *buffer = dd->buffer;
-  uint16_t written ;
+  size_t written;
   ssize_t nbytes;
 
   /* Is the out buffer full (or is this the last one)? */
@@ -391,7 +387,7 @@ int cmd_dd(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
   ret = dd_infopen(infile, &dd);
   if (ret < 0)
     {
-      goto errout_with_paths;
+      goto errout_with_alloc;
     }
 
   /* Open the output file */
@@ -475,6 +471,8 @@ errout_with_outf:
 
 errout_with_inf:
   close(dd.infd);
+
+errout_with_alloc:
   free(dd.buffer);
 
 errout_with_paths:
