@@ -124,10 +124,14 @@ int spicmd_exch(FAR struct spitool_s *spitool, int argc, FAR char **argv)
         {
           spitool_printf(spitool, "%02X ", txdata[d]);
         }
-      else
+      else if (spitool->width <= 16)
         {
           spitool_printf(spitool, "%04X ", ((uint16_t *)txdata)[d]);
         }
+      else
+        {
+          spitool_printf(spitool, "%08" PRIX32 " ", ((uint32_t *)txdata)[d]);
+        }
     }
 
   spitool_printf(spitool, "\n");
@@ -175,10 +179,14 @@ int spicmd_exch(FAR struct spitool_s *spitool, int argc, FAR char **argv)
         {
           spitool_printf(spitool, "%02X ", rxdata[d]);
         }
-      else
+      else if (spitool->width <= 16)
         {
           spitool_printf(spitool, "%04X ", ((uint16_t *)rxdata)[d]);
         }
+      else
+        {
+          spitool_printf(spitool, "%08" PRIX32 " ", ((uint32_t *)rxdata)[d]);
+        }
     }
 
   spitool_printf(spitool, "\n");
