@@ -545,6 +545,7 @@ static int wapi_essid_cmd(int sock, int argc, FAR char **argv)
 static int wapi_psk_cmd(int sock, int argc, FAR char **argv)
 {
   enum wpa_alg_e alg_flag;
+  enum wpa_ver_e ver_flag;
   uint8_t auth_wpa;
   int passlen;
   int cipher;
@@ -561,17 +562,39 @@ static int wapi_psk_cmd(int sock, int argc, FAR char **argv)
 
   /* Convert input strings to values */
 
-  alg_flag = (enum wpa_alg_e)wapi_str2ndx(argv[2], g_wapi_alg_flags);
-
   if (argc > 3)
     {
-      auth_wpa = atoi(argv[3]);
+      ver_flag = (enum wpa_ver_e)wapi_str2ndx(argv[3], g_wapi_wpa_ver_flags);
     }
   else
     {
-      auth_wpa = IW_AUTH_WPA_VERSION_WPA2;
+      ver_flag = WPA_VER_2;
     }
 
+  switch (ver_flag)
+    {
+      case WPA_VER_NONE:
+        auth_wpa = IW_AUTH_WPA_VERSION_DISABLED;
+        break;
+
+      case WPA_VER_1:
+        auth_wpa = IW_AUTH_WPA_VERSION_WPA;
+        break;
+
+      case WPA_VER_2:
+        auth_wpa = IW_AUTH_WPA_VERSION_WPA2;
+        break;
+
+      case WPA_VER_3:
+        auth_wpa = IW_AUTH_WPA_VERSION_WPA3;
+        break;
+
+      default:
+        return -EINVAL;
+    }
+
+  alg_flag = (enum wpa_alg_e)wapi_str2ndx(argv[2], g_wapi_alg_flags);
+
   switch (alg_flag)
     {
       case WPA_ALG_NONE:
@@ -591,7 +614,7 @@ static int wapi_psk_cmd(int sock, int argc, FAR char **argv)
         break;
 
       default:
-        return -1;
+        return -EINVAL;
     }
 
   ret = wpa_driver_wext_set_auth_param(sock, argv[0],
@@ -913,7 +936,7 @@ static int wapi_reconnect_cmd(int sock, int argc, FAR char **argv)
   load = wapi_load_config(argv[0], NULL, &conf);
   if (load == NULL)
     {
-      return -1;
+      return -EINVAL;
     }
 
   ret = wpa_driver_wext_associate(&conf);
@@ -955,7 +978,7 @@ static int wapi_save_config_cmd(int sock, int argc, FAR char **argv)
 
   if (!IFF_IS_RUNNING(if_flags))
     {
-      return -1;
+      return -EINVAL;
     }
 
   psk_len = sizeof(psk);
@@ -1081,7 +1104,7 @@ static void wapi_showusage(FAR const char *progname, int exitcode)
   fprintf(stderr, "\t%s essid        <ifname> <essid>      <index/flag>\n",
                    progname);
   fprintf(stderr, "\t%s psk          <ifname> <passphrase> <index/flag> "
-                  "<wpa>\n", progname);
+                  "[wpa]\n", progname);
   fprintf(stderr, "\t%s disconnect   <ifname>\n", progname);
   fprintf(stderr, "\t%s mode         <ifname>              <index/mode>\n",
                    progname);
@@ -1119,6 +1142,12 @@ static void wapi_showusage(FAR const char *progname, int exitcode)
       fprintf(stderr, "\t[%d] %s\n", i, g_wapi_alg_flags[i]);
     }
 
+  fprintf(stderr, "\nPassphrase WPA version:\n");
+  for (i = 0; g_wapi_wpa_ver_flags[i]; i++)
+    {
+      fprintf(stderr, "\t[%d] %s\n", i, g_wapi_wpa_ver_flags[i]);
+    }
+
   fprintf(stderr, "\nOperating Modes:\n");
   for (i = 0; g_wapi_modes[i]; i++)
     {
